package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````(`*``!````L1H!`#0```"\L@```@0`!30`(``)
M`"@`'``;``$``'!PIP``<*<!`'"G`0`(````"`````0````$````!@```#0`
M```T``$`-``!`"`!```@`0``!0````0````#````5`$``%0!`0!4`0$`&0``
M`!D````$`````0````$````````````!`````0!\IP``?*<```4```````$`
M`0```/2N``#TK@(`]*X"`$`"``"($@``!@```````0`"`````*\```"O`@``
MKP(```$````!```&````!`````0```!P`0``<`$!`'`!`0!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71D]*X`
M`/2N`@#TK@(`#`$```P!```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````$`````$```!'3E4```````(````&````(`````0````4
M`````P```$=.50!!S'SD]=65D.8F:#IJW(FYF7>4*F$````%````(`````H`
M``"@$@`(`D01(``"0`!6`'`8P@@`,`@`%1$``!`"`"@`````````2`(@"@`*
M``2$`ZA`"$5@:0"$"3Y"/)<``0`()%B`!`E@#)-X"4):`$``0``!`$()`$"`
MC,"$```0D!"#"0`(`1"`@4!`P@F`+$"8`D$`(``@!`F`E`&D#I=V0`4`````
M````!@````<````)``````````````````````````H````,````#@```!``
M```1````$@```!0````7`````````!D``````````````!H````=````'@``
M```````B````(P```"0`````````)0```"8````J`````````"P`````````
M`````"T````N````+P```#``````````-````#4`````````.0``````````
M````.@```#T````^`````````#\```!`````0@```$0```!'`````````$H`
M``!+````3````$T`````````3@``````````````````````````````````
M`$\```!0`````````%(`````````5````%8```!8````````````````````
M`````%D```!=`````````%\`````````80````````!C````9```````````
M````9@```&<```!I````:@```&T```!?EI,<HUKOD%;;DQS#CH?_#3J7"])1
M!(2!=((->O!*:WU!CL5V5#R4S3\,K_<CSB")!W#3('2P`M5DU'QFK\QF+DX]
M]MOW`%X&I(?_`:\TZ+%(G>?.2J[_SMY'+>&G`@KC1\8!Q@[@/3Y^EGSL/Y`"
M;7.%Q<6)!9!AF.\2`2/YI)V[DQQ"1=7L4.X1XX;YG(%][1$/NI63'%N:.P]!
M39U\I]VC:UGOEWDY\HL<#!3BG@0RI86B`O89V\WCGONA;&#JT^\.R#E`'S)B
MV^VYC?$.Z?O#PDHB??\*BA!7[=Z3'*U+X\#9<5@<*]#A(AJ?UKTM#K%S6#M`
M'\/E/RR8(M1HNN.2?"'_Y`Z*F-W";GII^HO9-5>3K01B-^/PP4/R[\C?A2!/
M5Z2;EL6YG$!0&WU?,;B"#;[:5QNS`8MOO-!+?7=OXW!J"4/6GR+'J"%B9`=^
MJ9R;8M#Z@NPL]HMK?YI\AO"6?-&?+/SN"U'Y\]O3'9!U@@U#9DL0!6RRS3RM
M.0T7ZEKQH^#[2>)7Q!A7DEI2_=+O#V[%WQ]\D!#I+=_^2"[%F[;>J\J?R=6R
M<0`````````````````````1```````````````@````+0``````````````
M(````#P``````````````"````!0```````````````@````A`,`````````
M````$@```$<"`````````````!(```#>`@`````````````2````P@(`````
M````````$@```'<$```DL0(``````"``%P#-`0`````````````2````NP(`
M````````````$@```+T!``#L%0$``````!(````#!0``V68!`#`````2``T`
MX`,``#2Q`@``````$``8`'4"`````````````!(```"@`@`````````````2
M````MP0``#"Q`@`$````$0`7`"$#`````````````!(````?!0``N6,!`-0"
M```2``T`7`0``!%9`0"H````$@`-`(L#`````````````!(```"&`@``````
M```````2````,@,`````````````$@```.\#``!\P0(``````!``&``/`0``
M```````````2````.@0`````````````$@```&@$``!=7`$`7`<``!(`#0"1
M!```X58!`)(````2``T`3P0``/E8`0`6````$@`-`*T"`````````````!(`
M``!P`@`````````````2````E@$`````````````$@````X#````````````
M`!(```">`P``.+$"``0````A`!@`+P(`````````````$@```#8"````````
M`````!(```#0`@`````````````2````S0,``#2Q`@``````$``7`.L"````
M`````````!(```">````+!@!```````2````M0(`````````````$@```%8#
M`````````````!(````I`@`````````````2````3P(`````````````$@``
M`)\#```XL0(`!````"$`&`#Z`P``?,$"```````0`!@`*P,``%"Q`@`$````
M$0`8``<$``!59P$``@```!(`#0"A`0`````````````2````;P$`````````
M````$@```*<$```99P$`/````!(`#0#C!```H5L!`+P````2``T`$00``%AG
M`0``````$@`.`(\"`````````````!(```![!```L1H!```````2``T`T`0`
M`%05`0``````$@`+`+X``````````````!(``````P`````````````2````
M`@$``$RQ`@`!````$0`8`,D"`````````````!(```""!```8&<!``0````1
M``\`U`,``#2Q`@``````$``8`%T#`````````````!(```!U`P``````````
M```2````:@``````````````$@```!P!`````````````!(```#.!```;58!
M`#`````2``T`.`$`````````````$@````($``!\P0(``````!``&`#6!```
M>5<!`'X!```2``T`TP``````````````$@```%X"`````````````!(```"'
M```````````````2````%0(`````````````$@```*\!`````````````!(`
M``#A```````````````2````\P``````````````$@```"T!``!(L0(`!```
M`!$`&`"=`P``.+$"``0````1`!@`80$`````````````$@```-<"````````
M`````!(```#N`P``?,$"```````0`!@`]00``$%;`0!0````$@`-`*\`````
M`````````!(````9`P`````````````2````=00``"2Q`@``````$``7`&<#
M`````````````!(```"[`P``0+$"``0````1`!@`*`0``)%;`0`0````$@`-
M`.L!`````````````!(```#8`0`````````````2````F`,``,$8`0#P`0``
M$@`-`#T!`````````````!(```!"`P`````````````2````.0,`````````
M````$@```/8!``!4L0(`$P```!$`&`#Y`@`````````````2````Y0(`````
M````````$@```'T"`````````````!(```#D`0`````````````2````?0,`
M````````````$@```,$$``"Y60$`B`$``!(`#0!)`P`````````````2````
M0@$`````````````$@```*<"`````````````!(```!#!```C68!`$P````2
M``T`>```````````````$@```'\!`````````````!(````7!```=5<!``0`
M```2``T`B`$`````````````$@```$X!``"T%P$``````!(`````;&EB<&5R
M;"YS;RXU+C(P`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?7V=M;VY?
M<W1A<G1?7P!?2G9?4F5G:7-T97)#;&%S<V5S`%])5$U?<F5G:7-T97)434-L
M;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7W-A
M=F5?9&5S=')U8W1O<E]X`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS=')U
M8W0`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]A=E]S:&EF=`!097)L7W-V
M7S)P=E]F;&%G<P!097)L7W-V7W-E='!V;@!03%]D;U]U;F1U;7``4&5R;%]N
M97=35G!V`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`
M4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`
M4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?9&]U;G=I;F0`4&5R;%]N
M97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A
M9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`
M4$Q?;65M;W)Y7W=R87``;&EB<'1H<F5A9"YS;RXP`'!T:')E861?9V5T<W!E
M8VEF:6,`8VQO<V4`;W!E;C8T`%]?97)R;F]?;&]C871I;VX`;'-E96LV-`!R
M96%D`&QI8F,N<V\N-@!?7W)E9VES=&5R7V%T9F]R:P!E>&ET`'-T<FYC;7``
M7U]S=')D=7``8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD
M:7(`<F5A;&QO8P!A8F]R=`!M96UC:'(`9V5T<&ED`'-T<G1O:P!S=')L96X`
M;65M<V5T`'-T<G-T<@!R;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P>0!?7W-T
M<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`<W1D97)R
M`&=E='5I9`!R96%D;&EN:P!E>&5C=G``7U]M96UC<'E?8VAK`'-T<F-H<@!R
M96%D9&ER-C0`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S=')C;7``
M7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`&QD+6QI;G5X+6%R;6AF+G-O
M+C,`7U]S=&%C:U]C:&M?9W5A<F0`7V5D871A`%]?8G-S7W-T87)T`%]?8G-S
M7W-T87)T7U\`7U]B<W-?96YD7U\`7U]E;F1?7P!?96YD`%]?;&EB8U]C<W5?
M9FEN:0!P87)?8W5R<F5N=%]E>&5C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W
M=6ED`'!A<E]C;&5A;G5P`'!A<E]B87-E;F%M90!P87)?9&ER;F%M90!P87)?
M;6MT;7!D:7(`7U]D871A7W-T87)T`%])3U]S=&1I;E]U<V5D`'!A<E]C=7)R
M96YT7V5X96-?<')O8P!?7VQI8F-?8W-U7VEN:70`;7E?<&%R7W!L`'!A<E]I
M;FET7V5N=@!X<U]I;FET`'!A<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB<&%T
M:`!P87)?96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0TQ%05)35$%#2P!8
M4U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXT`````````````````@`#
M``(``@`!`````@````$``0`"``(``0`"``$``0`"``(``@`!`````@`!``$`
M`0`"``(````"``(``P`#``(``0`"`````@`"``,``P`"``$``@`!```````!
M``$``0`"``$``0````(````"``$``0`"``(```````$````!``$````"````
M`P````````````(````"``$``0````(``0`"``0``0```````0`"``(``@``
M``(``@`"``(``@`!``(````"``$```````$```````$``0"G`P``$````"``
M```4:6D-```$`#4%`````````0`!``4"```0````(````!1I:0T```,`-04`
M```````!``$`5`(``!``````````%&EI#0```@`U!0```````""Q`@`5`@``
M.+$"`!1/``!`L0(`%%@``$BQ`@`43@``3+$"`!0[``!0L0(`%"\``%2Q`@`4
M8```#+`"`!8'```0L`(`%@4``!2P`@`6&@``&+`"`!8L```<L`(`%A<``""P
M`@`60```)+`"`!9=```HL`(`%D<``"RP`@`680``,+`"`!9>```TL`(`%@P`
M`#BP`@`68@``/+`"`!94``!`L`(`%D0``$2P`@`6.@``2+`"`!8V``!,L`(`
M%D@``%"P`@`6$```5+`"`!8>``!8L`(`%C$``%RP`@`64```8+`"`!9?``!D
ML`(`%F<``&BP`@`63```;+`"`!9:``!PL`(`%@8``'2P`@`6;@``>+`"`!9;
M``!\L`(`%E4``("P`@`6(P``A+`"`!9D``"(L`(`%A4``(RP`@`6,@``D+`"
M`!8"``"4L`(`%@@``)BP`@`6'P``G+`"`!8E``"@L`(`%FL``*2P`@`6*@``
MJ+`"`!89``"LL`(`%B0``+"P`@`65P``M+`"`!8Y``"XL`(`%F,``+RP`@`6
M(```P+`"`!9I``#$L`(`%E$``,BP`@`6;P``S+`"`!9!``#0L`(`%F@``-2P
M`@`6"@``V+`"`!8G``#<L`(`%D(``."P`@`6"P``Y+`"`!9E``#HL`(`%CP`
M`.RP`@`62P``\+`"`!8H``#TL`(`%C\``/BP`@`630``_+`"`!9L````L0(`
M%DD```2Q`@`6$@``"+$"`!8/```,L0(`%BD``!"Q`@`6*P``%+$"`!8A```8
ML0(`%A8``!RQ`@`62@``"$`MZ6`!`.L(@+WH!.`MY03@G^4.X(_@"/"^Y9":
M`0``QH_B&<J,XI#ZO.4`QH_B&<J,XHCZO.4`QH_B&<J,XH#ZO.4`QH_B&<J,
MXGCZO.4`QH_B&<J,XG#ZO.4`QH_B&<J,XFCZO.4`QH_B&<J,XF#ZO.4`QH_B
M&<J,XECZO.4`QH_B&<J,XE#ZO.4`QH_B&<J,XDCZO.4`QH_B&<J,XD#ZO.4`
MQH_B&<J,XCCZO.4`QH_B&<J,XC#ZO.4`QH_B&<J,XBCZO.4`QH_B&<J,XB#Z
MO.4`QH_B&<J,XACZO.5X1\!&`,:/XAG*C.(,^KSE`,:/XAG*C.($^KSE`,:/
MXAG*C.+\^;SE`,:/XAG*C.+T^;SE`,:/XAG*C.+L^;SE`,:/XAG*C.+D^;SE
M`,:/XAG*C.+<^;SE`,:/XAG*C.+4^;SE`,:/XAG*C.+,^;SE`,:/XAG*C.+$
M^;SE`,:/XAG*C.*\^;SE`,:/XAG*C.*T^;SE`,:/XAG*C.*L^;SE`,:/XAG*
MC.*D^;SE`,:/XAG*C.*<^;SE`,:/XAG*C.*4^;SE`,:/XAG*C.*,^;SE`,:/
MXAG*C.*$^;SE`,:/XAG*C.)\^;SE`,:/XAG*C.)T^;SE`,:/XAG*C.)L^;SE
M`,:/XAG*C.)D^;SE`,:/XAG*C.)<^;SE`,:/XAG*C.)4^;SE`,:/XAG*C.),
M^;SE`,:/XAG*C.)$^;SE`,:/XAG*C.(\^;SE>$?`1@#&C^(9RHSB,/F\Y7A'
MP$8`QH_B&<J,XB3YO.4`QH_B&<J,XASYO.4`QH_B&<J,XA3YO.4`QH_B&<J,
MX@SYO.4`QH_B&<J,X@3YO.4`QH_B&<J,XOSXO.4`QH_B&<J,XO3XO.4`QH_B
M&<J,XNSXO.4`QH_B&<J,XN3XO.4`QH_B&<J,XMSXO.4`QH_B&<J,XM3XO.4`
MQH_B&<J,XLSXO.4`QH_B&<J,XL3XO.4`QH_B&<J,XKSXO.4`QH_B&<J,XK3X
MO.4`QH_B&<J,XJSXO.4`QH_B&<J,XJ3XO.5X1\!&`,:/XAG*C.*8^+SE`,:/
MXAG*C.*0^+SE`,:/XAG*C.*(^+SE`,:/XAG*C.*`^+SE`,:/XAG*C.)X^+SE
M`,:/XAG*C.)P^+SE`,:/XAG*C.)H^+SE`,:/XAG*C.)@^+SE\+5+\D`7P/("
M!XFP.V@%D`6H!)$$J0.2`ZH'D__W*N]!\K1R0?8L`,#R`0+`\@$`$48$\`G_
M2_),$\#R`@,=>``M`/".@$OR2!3`\@($(&C_]]#OD/C>,P)&(&A#\`(#@OC>
M,__WQN\%FY_M75L%,P?ND#J?[5QKN.YG>S?N!7NT[L9[\>X0^I#XWB-"\`$"
M@/C>(P#SAH"8`$SR8";_]Z[N!)U+\BP1!9K`\@(!P/("!DQH`2I&]O0AP/(!
M`0-&*&A98$;V^"'`\@$!1OCP/!A@3_`$`-E@R+\I'4;X]`S(OP7K@@6<8,B_
M`_$,``7=4?@$2ZE"0/@$3_G1`O&`1$7RG6$#-``E5OCH#`,R`)7`\@$!0_@D
M4$SR8"7_]_SNP/("!01&B+-6^.@,3/)@)?_W-.Y&]J0`!JG`\@$`P/("!0/P
MQ?LXLU;XZ`S_]P#N__?6[@>:.V@@1II".-$)L/"]__<Z[DSR8"/`\@(#0_CH
M#'BS2_)(%/_WY.W`\@($(&C_]SCO@/@M5F#G5?CH#/_W_NX$1L?G5?CL#&"Q
M!/`5_M'G2_)4$4;VT!#`\@(!P/(!`/_W?.Y&]D``!JG`\@$``_"%^T7X[`P`
M*+S0YN?_]\KM`2#_]T+N`+^O\P"``````````````(#____/04_P``M/\``.
M`KQJ1@2T`;3?^!#`3?@$S0-(!$O_]P[N__?8[E5G`0#!&`$`&6<!`!0PG^44
M()_E`S"/X`(@D^<``%+C'O\O`0'__^H0E0$`(`$```=+2_(T$,#R`@`;&@8K
M!=E`\@`#P/(``P.Q&$=P1P"_-[$"`$OR-!-+\C00P/("`\#R`@`9&HD0`>O1
M<4D0!=!`\@`#P/(``P.Q&$=P1P"_$+5+\F<4P/("!"-X&[G_]\__`2,C<!"]
M2O;\8`BUP/("``-H$[F]Z`A`T^=`\@`#P/(``P`K]M"81_3G+>GP3TOR0!.M
M]3]]P/("`P)&.#(-\7@)&Y,;:`%&&I`!\7@,$$9.1@=&O9/-^"B0S>D,JY?H
M"@`(-V=%3^H3:T_J$R5/ZA%J3^H!(DKJ`RI/ZA$D`))$Z@-DS?@$H$_J`R)/
MZ@-N`I+=Z0`C3_```YE&3^H!803T?T`"]'\"3_```\WX#+`%DTM&0NH!`D_P
M``&`1HE&W>D"`4_P``$$E0#T?P#-^!BP0.H.`,WI"`%`1D#J`@!/\``!!Y%)
M1D'J`P$"1@KP_P`+1D+J``A/\``!0^H!"=WI!!)/\``"1ND"B0'T?T$(1A%&
MW>D((T+J``)#Z@$#$$891MWI!B-/\``#0^H!`P+P_P)"Z@`"&4801N;H!`&-
MT=WX*)`TJ"JI#?%H#@WQZ`Q/\$`(^>D"9_'I`B/PZ0)%S>D`9X+J!`:#Z@4'
M_ND"13)&.T;=Z0!G5D!?0&9`;T"T&;CQ`0A/ZM9Z3_```TKJ1PI*Z@0&,D;L
MZ0(CVM$:G`WU/GY^Z:(!U.D`(R5&S>D"`1=&F$8`(@`C^0[-Z0`C`)&21M3I
M"`$L1M7I`E:;1LWI!'AZ`<WI%`$`F<WI#%9%1D'J2!$`D>D.`9'4Z08!)4;=
MZ12)U>D$9\WI#@'=Z0(!#_;T5-3I`#00ZP@`S>D(9T'K"0$;&-WI#E9,0=WI
M#`'=Z0")S>D"-"7J``,FZ@$$2.H""`9&`D8E1@]&'$8+1MWI"`$&0`]`4$99
M1LWI``$T0]WI`@$]0T_JD@H?1A#K"`!*ZH=Z0?$``;L'$.L$"`&33_``!D_J
M@G/-^`2@3_``!P"30>L%"3-&S>D*B3Q&S>D"--WI`"-/\``)3_``"][I`D5"
MZ@H"3^I)$0.164801MWI!"/-Z08!3^K89@+J``H#Z@$+S>D`JT;J21;=Z0Z\
MW>D(`1OK!`L#EB#J`@(AZ@,#7$;=Z0"K3^I($0*12NH""@_V`%+2Z0`23.L%
M#$OJ`PL)&4_P``!"ZPP"$T8*1@`AS>D``=WI`@$P0Q+K"@9#ZPL'W>D$JS(8
M4T861D_JDP,`DP":1_$``UE&4$8?1D+JBW,`DXL(`9,`(@`CS>D"(]WI`".R
M1LWI$&>$!_8.`I8B0P*;3_``"P`G%D9#ZDL3`I-/ZDH0W>D*(][I!$4R0#M`
MS>D*9Q9&'T;=Z0@C$AE/ZMMD:T$#E`_V6$75Z0!%I!A/\``"74'-Z1)%W>D&
M-"3J"00CZ@@#'D,`(R5&+T,T1CU&W>D"9\WI`"-/ZI@#W>D2$@9#`)-/ZHAP
M"1EJ015&BAE%\0`#`"&01A5&'D8`F\WI$E9/ZMAF0^J)<P"33^J9`P&3W>D`
M(P`CWND&14_P``D"0T;J21801@`BS>D`(P_VS#/3Z0`C$AE/ZDD4:T$!E-WI
M$$7-Z1`!!$`-0`&6($8I1MWI!D6D&%U!S>D"1=WI"C0-1D_J2!$`D2/J"@,D
MZ@L$&D8C1@1&'4,40]WI``$K1B)&W>D"13!#3^J*=J083_```EU!`"/-Z0(C
M(AA/ZIH#`I-%\0`#$4;>Z0A%BD8:1@*;S>D6$@`A0^J+<P*33^J;`P.3W>D"
M(P`C3_``"S)#3^K:9D;J2Q801@`BS>D`(P_V&#/3Z0`CS>D&`1(93^I+%&M!
M`93=Z1)%`98$0`U`($8I1MWI"D6D&%U!S>D"1=WI$#0-1D_J2A$`D2/J"`,D
MZ@D$&D8C1@1&'4,40]WI``$K1B)&W>D"13!#3^J(=J083_```EU!`"/-Z0(C
M(AA/ZI@#`I-%\0`#$4;>Z0I%B$8:1@*;S>D2$@`A0^J)<P*33^J9`P.3W>D"
M(P`C3_``"3)#3^K89D;J21801@`BS>D`(P_V9"/3Z0`CS>D*`1(93^I)%&M!
M`93=Z19%`98$0`U`($8I1MWI$$6D&%U!S>D"1=WI!C0-1D_J2!$`D2/J"@,D
MZ@L$&D8C1@1&'4,40]WI``$K1B)&W>D"13!#3^J*=J083_```EU!`"/-Z0(C
M(AA/ZIH#`I-%\0`#$4;>Z0Q%BD8:1@*;S>D6$@`A0^J+<P*33^J;`P.3W>D"
M(P`C3_``"S)#3^K:9D;J2Q801@`BS>D`(P_VL!/3Z0`CS>D0`1(93^I+%&M!
M`93=Z1)%`98$0`U`($8I1MWI!D6D&%U!S>D"1=WI"C0-1D_J2A$`D2/J"`,D
MZ@D$&D8C1@1&'4,40]WI``$K1B)&W>D"13!#3^J(=J083_```EU!`"/-Z0(C
M(AA/ZI@#`I-%\0`#$4;>Z0Y%B$8:1@*;S>D2$@`A0^J)<P*33^J9`P.3W>D"
M(P`C3_``"3)#3^K89D;J21801@`BS>D`(P_V_`/3Z0`CS>D&`1(93^I)%&M!
M`93=Z19%`98$0`U`($8I1MWI"D6D&%U!S>D"1=WI$#0-1D_J2!$`D2/J"@,D
MZ@L$&D8C1@1&'4,40]WI``$K1B)&W>D"13!#3^J*=J083_```EU!`"/-Z0(C
M(AA/ZIH#`I-%\0`#$4;>Z1!%BD8:1@*;S>D6$@`A0^J+<P*33^J;`P.3W>D"
M(P`C3_``"S)#3^K:9D;J2Q801@`BS>D`(P_V2`/3Z0`CS>D*`1(93^I+%&M!
M`93=Z1)%`98$0`U`($8I1MWI$$6D&%U!S>D"1=WI!C0-1D_J2A$`D2/J"`,D
MZ@D$&D8C1@1&'4,40]WI``$K1B)&W>D"13!#3^J(=J083_```EU!`"/-Z0(C
M(AA/ZI@#`I-%\0`#$4;>Z1)%B$8:1@*;S>D2$@`A0^J)<P*33^J9`P.3W>D"
M(P`C3_``"3)#3^K89D;J21801@`BS>D`(P_RE'/3Z0`CS>D0`1(93^I)%&M!
M`93=Z19%`98$0`U`($8I1MWI!D6D&%U!S>D"1=WI"C0-1D_J2!$`D2/J"@,D
MZ@L$&D8C1@1&'4,40]WI``$K1B)&W>D"13!#3^J*=J083_```EU!`"/-Z0(C
M(AA/ZIH#`I-%\0`#$4;>Z11%BD8:1@*;S>D6$@`A0^J+<P*33^J;`P.3W>D"
M(P`C3_``"S)#3^K:9D;J2Q801@`BS>D`(P_RX&/3Z0`CS>D&`1(93^I+%&M!
M`93=Z1)%`98$0`U`($8I1MWI"D6D&%U!S>D"1=WI$#0-1D_J2A$`D2/J"`,D
MZ@D$&D8C1@1&'4,40]WI``$K1B)&W>D"13!#3^J(=J083_```EU!`"/-Z0(C
M(AA/ZI@#`I-%\0`#$4;>Z19%B$8:1@*;S>D2$@`A0^J)<P*33^J9`P.3W>D"
M(P`C3_``"3)#3^K89D;J21801@`BS>D`(P_R+&/3Z0`C$AE/ZDD4:T$!E-WI
M%D7-Z0H!!$`-0`&6($8I1MWI$$6D&%U!S>D"1=WI!C0-1D_J2!$`D2/J"@,D
MZ@L$&D8C1@1&'4,40]WI``$K1B)&W>D"13!#3^J*=J083_```EU!`"/-Z0(C
M(AA/ZIH#`I-%\0`#$4;>Z1A%BD8:1@*;S>D6$@`A0^J+<P*33^J;`P.3W>D"
M(P`C3_``"S)#3^K:9D;J2Q801@`BS>D`(P_R>%/3Z0`CS>D0`1(93^I+%&M!
M`93=Z1)%`98$0`U`($8I1MWI!D6D&%U!S>D"1=WI"C0-1D_J2A$`D2/J"`,D
MZ@D$&D8C1@1&'4,40]WI``$K1B)&W>D"13!#3^J(=J083_```EU!`"/-Z0(C
M(AA/ZI@#`I-%\0`#$4:(1AI&`IM#ZHES`I-/ZID#`Y/-Z1(23_``"=WI`B,`
M(][I&D4`(3)#3^K89D;J21801@`BS>D`(P_RQ$/3Z0`CS>D&`1(93^I)%&M!
M`93=Z19%`98$0`U`($8I1MWI"D6D&%U!S>D"1=WI$#0-1D_J2!$`D2/J"@,D
MZ@L$&D8C1@1&'4,40]WI``$K1B)&W>D"13!#3^J*=J083_```EU!`"/-Z0(C
M(AA/ZIH#`I-%\0`#$4;>Z1Q%BD8:1@*;S>D6$@`A0^J+<P*33^J;`P.3W>D"
M(P`C3_``"S)#3^K:9D;J2Q801@`BS>D`(P_R$$/3Z0`CS>D*`1(93^I+%&M!
M`93=Z1)%`98$0`U`($8I1MWI$$6D&%U!S>D"1=WI!C0-1D_J2A$`D2/J"`,D
MZ@D$&D8C1@1&'4,40RM&(D;=Z0)%I!A/\``"74$`(\WI`B-/ZI@#W>D``0*3
M,$-/ZHAV(AA%\0`#WND>11%&&D8"F\WI$A*(1D/JB7,"DT_JF0,#D]WI`B,`
M(T_P``D`(3)#3^K89D;J21801@`BS>D`(]>CT^D`(\WI$`$2&4_J211K00&4
MW>D610&6!$`-0"!&*4;=Z09%I!A=0<WI`D7=Z0HT#49/ZD@1`)$CZ@H#).H+
M!!I&(T8$1AU#%$/=Z0`!*T8B1MWI`D4P0T_JBG:D&$_P``)=00`CS>D"(R(8
M3^J:`P*31?$``Q%&WND@18I&&D8"F\WI%A(`(4/JBW,"DT_JFP,#D]WI`B,`
M(T_P``LR0T_JVF9&ZDL6$$8`(LWI`".KH]/I`"/-Z08!$AE/ZDL4:T$!E-WI
M$D4!E@1`#4`@1BE&W>D*1:0874'-Z0)%W>D0-`U&3^I*$0"1(^H(`R3J"00:
M1B-&!$8=0Q1#W>D``2M&(D;=Z0)%,$-/ZHAVI!A/\``"74$`(\WI`B,B&$_J
MF`,"DT7Q``,11M[I(D6(1AI&`IO-Z1(2`"%#ZHES`I-/ZID#`Y/=Z0(C`"-/
M\``),D-/ZMAF1NI)%A!&`"+-Z0`C?J/3Z0`CS>D*`1(9:T'-Z0(C3^I)$P&3
MW>D6(]WI$$4"0`M``9801AE&W>D"(Q(9:T$41AU&S>D"1=WI!C0-1D_J2!$`
MD2/J"@,DZ@L$&D8C1@1&'4,40]WI``$K1B)&W>D"13!#3^J*=J083_```EU!
M`"/-Z0(C(AA/ZIH#`I-%\0`#`"4<1A-&`IJ:1D+JBW("DD_JFP(#DLWI$#0`
M)-WI`B-/ZMICS>D`14_P``O>Z20!,D-1I=7I`$4`)@"3-T8D&!9&34'-Z0)G
MW>D2`0">.4`00$;J2Q8`EMWI!F=/ZDH2-AEO031&/4;=Z0IG)NH(!B?J"0<&
M0P]#,!E/ZMMA`9%'ZP4!W>D`9P`D`"460RM&(D;-Z0`C@AE/ZHES`9-!\0`#
M3^J8!!%&1.J)=!I&`91/ZHAS`)-/ZID%S>D2$@A&W>D`(T_P``A!1@_RK`G9
MZ0")(D,K0T8!%T841AU&`"(`(\WI`"/##@"3WNDF(\WI!D4`)0"<$NL(`D/K
M"0.I1D3J010`E-WI$$6X1LWI$(D%Z@D%W>D*B3Q`&.L""$GK`PG=Z0(C(NH*
M`B/J"P,B0RM#&.L""$_JT61)ZP,)`91"1D_JBG1+1MWI`(E(Z@8($NL(!D/Q
M``=/ZIH#,D9#ZHMSN$8`DS=&3^J;!LWI"G@=1@7@K_,`@)EY@EH``````99/
M\``(W>D`9T-&)D,O0]0.L4;=Z096ND;-Z0::A>H)!0_VG&O;Z0"K1.I#%`"4
MJ$;>Z2A65`$5ZPH%1NL+!MWI$KR+Z@@+-T;>#@&6V$;=Z0*K&NL%"D_P``5+
MZP<+&NL(!DOQ``?=Z0"K2NH$"H0'%NL*"$_JD`9'\0`)1NJ!=H\(WNDJ`<I&
MP4;-Z1*:3_``"M%&1^H&"T;J!`H`),WI`$5/ZMADW>D&5LWI`JN%Z@H%W>D*
MO`"4+D8/]@!EU>D`18OJ!@LD&$_J2!!>1MWI$*M-00"9&NL$"D_JV61!ZDD1
M`90`D4OK!0L:ZP8$3_```4OQ``7=Z0"K2NH`"I`'%.L*!D_JD@1%\0`'1.J#
M=+)&G0B[1LWI$*M/\``+WNDL(U]&1.H`"P`@S>D``?$.`)$/]HA1T>D``47J
M!`S=Z0)%@!C-Z0J\64'-Z18!!IB$Z@L$`)MR`=WI$JM#ZD<3A$8`DXKJ!`K=
MZ18!5$80ZPP`0?$``0`9BT9/ZM=A`9%+\0`!W>D`JP_V-%S<Z0"\2NH""D_J
MB'(0ZPH$3^J8`$#JB7!!\0`%3^J9`4#J`@E!Z@`*S>D214E&W>D*B5)&S>D&
M$HCJ`0C>Z2X!`"7C#A#K"P#=Z1"K0>L,`<WI%@$"F(KJ"`I#ZD43`)/01F(!
MA$;=Z18!$.L,`$'Q``$0ZP@`BT9/ZM5A`9%+\0`!W>D`JTKJ`@JR!Q#K"@A/
MZI8`0?$`"4#JAW"Y"$#J`@9!Z@`'S>D0B;)&3_``";M&W>D&9\WI`JM11@_V
M=$S<Z0"\3D#>Z3`!3^K88T/J21,`DQ#K"P#=Z1*K0>L,`<WI%@$*F(KJ!@I/
MZD@2`"-61H1&W>D6`1#K#`!!\0`!@!F+1D_JV6$!D4OQ``'=Z0"K2NH""J('
M$.L*!D_JE`!`ZH5P0?$`!T#J`@2I"$'J``7>Z3(!HD8`),WI`#2S1MWI`C2\
M1LWI$KRK1H/J"@/-Z0JK3_``#!Q&\PX`DV=&#_;0,]/I`".`&$_J1A)90<WI
M%@$`FP:80^I,$]WI$*L`DX1&W>D6`8KJ!`H0ZPP`0?$``51&`!F+1D_JUV$!
MD4OQ``'=Z0"K2NH""D_JB'(0ZPH$3^J8`$#JB7!!\0`%3^J9`4#J`@E!Z@`*
M3_``"$E&3_``"<WI`(E21MWI"HGC#LWI!A(`DXCJ`0@/]D0ST^D`(][I-`'=
MZ1*K@!C-Z1!%64'-Z18!`IB*Z@@*`)L`)=!&8@&$1MWI%@%#ZD43`),0ZPP`
M3_```T'Q``$0ZP@`BT9/ZM5A`9%+\0`!W>D`JTKJ`@JR!Q#K"@A/ZI8`0?$`
M"4#JAW"Y"$#J`@M!Z@`,`"+>Z38!S>D`(T_JV&,`DP_VO"/3Z0`CW>D&9X`8
MS>D2B5E!S>D6`0J83_``"0";ANH+!LWI`KQ/ZD@20^I)$]WI$*N$1@"3W>D6
M`8KJ!@H0ZPP`5D9!\0`!@!F+1D_JV6$!D4OQ``'=Z0"K2NH""J('$.L*!D_J
ME`!`ZH5P0?$`!T#J`@2I"$'J``6R1B%&W>D"-+M&S>D0JT_P``LJ1E]&S>D*
M$@_V*"S<Z0"\2T#>Z3@!<@$<1O,.$.L+`-WI$JM!ZPP!S>D6`0:8BNH$"D/J
M1Q,`DU1&`".$1MWI%@$0ZPP`0?$``0`9BT9/ZM=A`9%+\0`!W>D`JTKJ`@I/
MZHAR$.L*!$_JF`!!\0`%0.J)<$_JF0%`Z@()0>H`"@`BWNDZ`<M&S>D`(^,.
M`)/41@_VG!/3Z0`CW>D*B8`8S>D&O%E!S>D6`0*8B.H+"-WI$*MB`0";A$;=
MZ18!BNH("LWI$D40ZPP`3_``!4'Q``%#ZD43T$8`DXM&$.L(`$_JU6$!D4OQ
M``'=Z0"K2NH""K('$.L*"$_JE@!!\0`)0.J'<+D(0.H""D'J``O=Z09G4$;-
MZ1")649&0$]`S>D"`<WI`&=/\``)WND\$D_JV&H/]OP'U^D`9TKJ21H*FXD9
M>D'=Z0!GS>D6$J\(W>D2$LWX!*!.0-WI%@'`&$'Q``&"&4_JE`9/ZH1P1NJ%
M=M[I/D5!\0`#S>D*(T_J2!,`D]WI`",-];A^S>D`14;J``3=Z0(!1^H&!4+J
M"@+=Z0JK8$`N1B5&S>D*5@_VA`75Z0!%!D;=Z0`!&NL""DOQ``O-Z1*K`!E2
M1FE!3_``"P1&!I@-1LWI%D7=Z1!%3^K::DKJ2QK-^`2@=$!;1D_JF0<F1MWI
M%D4D&$7Q``6@&47Q``'-Z08!40$`D=WI``%/ZI@&W>D&O$;JB79`Z@H`3^J(
M=!OK``M/\``(3_``"<WI`(E81D;J!`A'Z@8)3^K09`"41T9,\0`,R$;-Z1:\
M3_``#-[I`*MA1LWI!G@-];Q^W>D*5@">?4`/\L1YV>D`B4;J3!8`EMWI$F<8
MZPH(2>L+"0`G;D`"G1CK!01/ZD`82?$`!:)&S`X:ZP8*`91%\0`+W>D`10`F
MS>D`9T3J"`3-Z0)G&NL$"$_JD@0`E$_J@W0#E$OQ``D`G)X(`9;*1D3J@W0`
ME`.<DP<"D\%&1.J2!`.4W>D`9T1&S>D2FD_P``K=Z0*)54;>Z0`C3^K4:DCJ
M!@A)Z@<)2NI%&LWX!*!&1D]&W>D&B0WUP'[-Z1!G3^J<"8CJ!@@/\@1WU^D`
M9P`AMAA?0<WI`F?=Z19G"IN&Z@@&L$;=Z0)G]AA'\0`'%NL(`D?Q``/-Z0(C
M8P$`D]WI`"-/ZI`(2.J,>(8'0NH*`MWI`JL`(!KK`@I+\0`+S>D6JT_P``M2
M1EM&WND`J\WI``%(Z@8`2>H(`0=&T`Z(1@"0W>D0`<WI"GB!Z@@!#_)\:=GI
M`(D`GGA`&.L*"$;J0QX&GL)&W>D2>$GK"PG-^`#@1T"(Z@$(S>D">!KK!@A/
MZM-F`98"GDGQ``D`)Z$(&.L&"D_P``9)\0`+W>D`B<WI`&=0`0"1J0?-Z0)G
M2.H`"`.1&NL("`"93^J5!@&60$9!ZH5Q`)$#F4OQ``G=Z0!G#?7$?D'JE`&D
M!P.13_``"@*444;-Z0:)3^K0:MWI`HE*ZD$:WND`10WUR'Y(Z@8(2>H'"49&
M3T;=Z0J)3^J3"<WI$F>(Z@8(#_*P5]?I`&<V&6]!S>D"9]WI%E:%Z@@%J$80
MG=WI`F?-^`2@=AE'\0`'%NL(!$?Q``7-Z0)%1`$`E-WI`$5/ZI((2.J#>)8'
M1.H*!-WI`JL`)4GJ"`P:ZP0*2_$`"\WI&*M41LWI`$5(Z@8+`)[>Z0!%#?7,
M?@_R/%K:Z0":W>D2>/(.%.L)!`J>W>D&B47K"@6'Z@L'HD8:ZP8&`9R(Z@<(
M1?$`!P"=%NL("D+J1!(#DLWI$+Q'\0`+;`$"E(0(W>D"9T3J@70"E!9#`"4C
M1HP(`Y0:ZP8(3_``!,WI!D7=Z0)%2_$`"8('1D840QU#WND``<I&\P[!1@:3
MJT;-Z0J:3_``"MWI$(E71@_RI$/3Z0`CHD;-Z1:KB.H$"-WI&*L2&$M!$IB*
MZ@@*^0X=1@:;T$82ZP`*1?$`"QKK"`!#ZD<3!I,'D4OQ``'=Z0:K<@%/\``(
M3_``"4KJ`@I#1A#K"@),1LWI`C1!\0`#$48-]=!^&D8`F\WI!A(`(@A&$49/
MZI,(`9O>Z0"KQ`Y$ZD$4#?74?IL'`Y,!FTCJ@W@!F\WX#(!/ZI,)`)N;!P*3
MW>D"(T+J"`)#Z@D#D$:91MWI%B/-Z1*)@NH(`H/J"0,/\N`YV>D`B1CK"@A)
MZPL)PD;+1MWI"HF(Z@((B>H#"0`B`"/-Z0`C2P$!DQ";S>D"B1KK`PA/ZD`3
M`)-+\0`)`IL!E!CK`PK=Z0`C2?$`"T_JE@@B0TCJAW@:ZP($S?@$@$OQ``5/
MZI<)(T9/\``*+$;-Z1`T`"0:1B-&M`<`E$_P``O=Z0!%S>D"JT3J"`1%Z@D%
MWND`9Z)&JT;5#@*5W>D21<WI"JN$Z@H$#_(T.MKI`)K=Z0:\&>L&"1:=2NL'
M"HOJ!`L`)@`GS>D`9\A&`IY4`0"4`"1&ZD,>7@'-^`C@`99>1LWX!.`8ZP4+
M3^K390.52O$`#!OK!@C=Z0)G3_``!=WI`*M/ZI$'S>D&14_J@'1*Z@8*3^J0
M!@:63/$`"0:>&.L*"P>72?$`#$;J@78&EMWI!@'91MWI"G@U1B!#;*X'0^)&
MS>D6FD_P``K-Z0*:@D8X1MWI$'@I0];I`$4"G@=`BT;-Z1"KN$8/\GPLW.D`
MO$_JUF[=Z0IG&^L$"P.9!NH*!DSK!0Q(Z@8`$IY.ZD$>S?@`X!OK!@C=Z0)G
M3/$`"90(1.J#=`WUW'[]#D_J1AH!E1CK``9)\0`'W>D`B9T(D`=(Z@H(1.H`
M"Q;K"`A%Z@0,1_$`"0`C1T8`),A&S>D8>$_P``C-Z0!XS>D&-`"<W>D0B0&:
MY0X&E=WI%D5(Z@L#WND``1Q`!IL/\M@:VND`FB9&".H+!`J=0^I"$S)&(D,!
MG!GK``E*ZP$*&>L%"`"92O$`"0:3X`X8ZP($!Y!)\0`%W>D&B4_J01K-Z1*\
M2.H*",)&W>D">$9&N`@4ZPH(3^J&<]WI`F=%\0`)<*S*1L%&0.J'<$/JE@.Y
M"+('S>D6FD_P``I71D'J`PM`Z@(*`"/4Z0`!`"3-Z0(T1D;=Z1(TV4;U#@*5
M0^H*`T3J"P3=Z1B\T$8:1B-&#.H##`*;"^H""\WI!KS=Z1*\S>D*B9Y&#_(0
M&=GI`(D+Z@H+W>D&(T[J1QX0G1CK``A<1DGK`0DB0QCK!0A)\0`)_0X8ZP($
MS?@(X`.52?$`!<WI!F=/ZD8:W>D"B0">2.H*"!3K"`ARK$7Q``FP"`"=`9[-
MZ1B)3_``":H'149`ZH9PL0A`Z@(*0>H`"P`FS>D`5M3I``%51EY&`)S=Z0JK
M3_``",WI`HFH1K%&S>D0B5)&*D/E#@*5W>D610*;%$`!FA*=)D941@_R7`K:
MZ0":!.H(!$/J0A,R1B)#`9P9ZP`)`I-*ZP$*&>L%"`"92O$`">`.&.L"!`.0
M2?$`!=WI`HE/ZD$:2.H*",)&W>D&>$9&N`BS!]WI!F<)X*_S`("AZ]EN````
M`-R\&X\`````%.L*"'2L1?$`"4#JAW!#ZI8#N0BR!T#J`@M!Z@,,U.D``0`C
M`"3-Z0(TW>D0-,I&P4;-Z1::3_``"D9&5T;81D/J"P-$Z@P$W>D8J_4.`I7A
M1AI&S>D2B2-&"NH""@OJ`PO-Z0:KW>D0O$_J1AH"FPOJ"`L/]K!IV>D`B0J=
MGD;=Z08C&.L`"%Q&2>L!"2)#&.L%"$[J1QY)\0`)S?@(X!CK`@1/ZM=E`Y5)
M\0`%W>D"B<WI!F<`GDCJ"@@4ZP@(=JQ%\0`)`)VP"`&>S>D8B4_P``FJ!T5&
M0.J&<+$(0.H""D'J``L`)LWI`%;4Z0`!549>1@"<W>D2JT_P``C-Z0*)J$:Q
M1LWI"HE21BI#Y0X"E=WI%D4"FQ1``9H0G29&5$8/]@1JVND`F@3J"`1#ZD(3
M,D8B0P&<&>L`"0*32NL!"AGK!0@`F4KQ``G@#ACK`@0#D$GQ``7=Z0*)3^I!
M&DCJ"@C"1MWI!GA&1K@(LP?=Z09G%.L*"'BL1?$`"4#JAW!#ZI8#N0BR!T#J
M`@M!Z@,,RD;4Z0`!P48`(\WI%IH`),WI`C1/\``*W>D*-$9&5T;81D/J"P-$
MZ@P$W>D8J_4.`I7A1AI&(T8*Z@(*"^H#"P*;S>D&JT_J1AK=Z0J\S>D0B9Y&
M"^H("P_V/%G9Z0")W>D&(T[J1QX2G1CK``A<1DGK`0DB0QCK!0C-^`C@2?$`
M"?T.&.L"!`.52?$`!=WI`HG-Z09G`)Y(Z@H(%.L("'JL1?$`"0"=L`@!GLWI
M&(E/\``)J@=%1D#JAG"Q"$#J`@I!Z@`+`";-Z0!6U.D``55&7D8`G-WI$*M/
M\``(S>D"B:A&L4;-Z1*)4D8J0^4.`I7=Z19%`IL40`&:"ITF1E1&#_:02MKI
M`)H$Z@@$0^I"$S)&(D,!G!GK``D"DTKK`0H9ZP4(`)E*\0`)X`X8ZP($`Y!)
M\0`%W>D"B4_J01I(Z@H(PD;=Z09X1D:X"+,'W>D&9Q3K"@A\K$7Q``E`ZH=P
M0^J6`[D(L@=`Z@(+0>H##-3I``$`(P`DS>D"--WI$C3*1L%&S>D*FD_P``I&
M1E=&V$9#Z@L#1.H,!-WI&*OU#@*5X48:1B-&"NH""@OJ`PL"F\WI%JM/ZD8:
MW>D2O,WI!HF>1@OJ"`L/]L@YV>D`B1"=3NI''MWI%B,8ZP`(7$9)ZP$)(D,8
MZP4(S?@(X$GQ``G]#ACK`@0#E4GQ``7=Z0*)#?4`?LWI$&<`GDCJ"@@4ZP@(
M?JQ%\0`)`)VP"`&>S>D`B:H'U.D`14#JAG"Q"$#J`@I!Z@`+W>D&(P`F4$99
M1@)#"T,W1D9&$$891MWI"B/01ME&S>D*B0)`"T#-Z0(C0$;=Z08C3^K6:@_V
M)#G9Z0")2NI'&@)`$IO=Z0(!&.L$"$GK!0E/ZM=K$$,8ZP,"2?$``T_J1A@2
M&$/Q``/-Z0(C2.H*`DKJ"P/-Z1(CW>D0B=WI`JM#1IP($IM$ZHET&NL#"DM&
M3^J3!4-&3^J#<-!&2_$`"\WI$*M$Z@`*WND``47J!`M/\``)4T9/ZMAJS>D2
M`5Q&W>D*$DKJ21K-Z0(T#?44?AE#(D/=Z0`T"$840`-`W>D*$LWI`#3=Z0(T
M#_9P)=7I`$490``C"D;=Z1(!`!EI001&#4;=Z0`!$$,`(LWI`"-/ZDD3`9,&
MF\WX!*#B&$_J2!1%\0`#`)02&$_JE@1#\0`#S>D&(]WI`"-$ZH=TO0BP!T+J
M"@+=Z0:K`"<:ZP(*W>D"(TOQ``O-Z1*K5D9%Z@0+1.H`"H*M648+0U!&`D/-
MZ08!&4801MWI$"/5Z0!%3^K6:@)`"T#=Z08!2NI'&LWI`"/=Z0(C`","0`_V
MO!'1Z0`!`!EI001&#4;=Z0`!$$,`(LWI`"-[`0&3"IO-^`2@XAA/ZD841?$`
M`P"4$AA/ZI@$0_$``\WI"B/=Z0`C1.J)=$_JF05/ZHAP0NH*`MWI"JM/\``)
M&NL""DOQ``O-Z1"K1>H$"X2MT$9$Z@`*U>D``5Q&4T;-Z0HT3^K8:LWI``%*
MZDD:W>D&$AE#(D/=Z1)%"$850`1`W>D&$LWI$D7=Z0HT#_84%=7I`$490``C
M"D;=Z0`!`!EI001&#4;=Z1(!$$,`(LWI`"-/ZDD3`9,"F\WX!*#B&$_J2!1%
M\0`#`)02&$_JE@1#\0`#S>D"(]WI`"-$ZH=TO0BP!T+J"@+=Z0*K`"<:ZP(*
MW>D*(TOQ``O-Z1*K5D9%Z@0+1.H`"H:M648+0U!&`D/-Z0(!&4801MWI$"/5
MZ0!%3^K6:@)`"T#-Z0`C2NI'&MWI"B,`(]WI`@$"0`_V8`'1Z0`!`!EI001&
M#4;=Z0`!$$,`(LWI`"-[`0&3!IO-^`2@XAA/ZD841?$``P"4$AA/ZI@$0_$`
M`\WI!B/=Z0`C1.J)=$_JF05/ZHAP0NH*`MWI!JM/\``)&NL""DOQ``O-Z1"K
M1>H$"XBMT$9$Z@`*U>D``5Q&4T;-Z08T3^K8:LWI``%*ZDD:W>D"$AE#(D/=
MZ1)%"$850`1`W>D"$LWI$D7=Z08T#_*X==7I`$490``C"D;=Z0`!`!EI001&
M#4;=Z1(!$$,`(LWI`"-/ZDD3`9,*F\WX!*#B&$_J2!1%\0`#`)02&$_JE@1#
M\0`#S>D*(]WI`"-$ZH=TO0BP!T+J"@+=Z0JK`"<:ZP(*W>D&(TOQ``O-Z1*K
M5D9%Z@0+1.H`"HJM648+0U!&`D/5Z0!%3^K6:LWI"@$01AE&W>D0(TKJ1QH"
M0`M`W>D*`<WI`"/=Z08C`","0`_R!''1Z0`!`!EI001&#4;=Z0`!$$,`(LWI
M`"-[`0&3`IO-^`2@XAA/ZD841?$``P"4$AA/ZI@$0_$``\WI`B/=Z0`C1.J)
M=$_JF05/ZHAP0NH*`MWI`JM/\``)&NL""DOQ``O-Z1"K1>H$"XRMT$9$Z@`*
MU>D``5Q&4T;-Z0(T3^K8:LWI``%*ZDD:W>D*$AE#(D/=Z1)%"$850`1`W>D*
M$LWI$D7=Z0(T#_)<9=7I`$490``C"D;=Z0`!`!EI001&#4;=Z1(!$$,`(LWI
M`"-/ZDD3`9,&F\WX!*#B&$_J2!1%\0`#`)02&$_JE@1#\0`#S>D&(]WI`"-$
MZH=TO0BP!T+J"@+=Z0:K`"<:ZP(*2_$`"\WI$JM61D7J!`M$Z@`*W>D"(UE&
MCJU01@M#`D/-Z08!&4;5Z0!%$$;=Z1`C3^K6:@)`"T#=Z08!2NI'&LWI`"/=
MZ0(C`","0`_RJ%'1Z0`!`!EI001&#4;=Z0`!$$,`(LWI`"-[`0&3"IO-^`2@
MXAA/ZD841?$``P"4$AA/ZI@$0_$``\WI"B/=Z0`C1.J)=$_JF05/ZHAP0NH*
M`MWI"JM/\``)&NL""DOQ``O-Z1"K1>H$"Y"MT$9$Z@`*U>D``5Q&4T;-Z0HT
M3^K8:LWI``%*ZDD:W>D&$AE#(D/=Z1)%"$850`1`W>D&$LWI$D7=Z0HT#_(`
M5=7I`$490``C"D;=Z0`!`!EI001&#4;=Z1(!$$,`(LWI`"-/ZDD3`9,"F\WX
M!*#B&$_J2!1%\0`#$AA#\0`#`)3-Z0(CM`C=Z0`C1.J'=-WI`KR]"$+J"@*P
M!QOK`@M/\``'3/$`#,WI$KQ%Z@0,DJU>1D3J``O5Z0`C\`[=Z0I%0.I'$,WI
M`KQ$Z@L$W>D0JT7J#`4!D`KJ!`H+Z@4+W>D*14_JF07-Z1"KW>D"JP3J"@0/
M\DA+V^D`JQKK`@I+ZP,+W>D0(P:;%$,:ZP,*3^I&$P"32_$`"]WI`",:ZP0*
M2_$`"T_JF`0"0T3JB70:ZP(``91+\0`!"D8!1LWI$!)/ZHAQ`"(`D1-&`D;=
MZ0`!3^K2:MWI`HE*ZD,:($,I0XCJ``C>Z0!%S>D&`4_JEPGUH='I``$-]1I^
MS?@$H"08"IA-0<WI%D7=Z1)%A.H(!*!&W>D612081?$`!13K"`!%\0`!S>D*
M`5$!`)'=Z0`!3^J6"$CJAWB6KT#J"@#=Z0JKM`<:ZP`*2_$`"\WI$JO7Z0!G
M4$9/\``+3^K::DKJ2QI91LWI`&=(Z@0&2>H(!]WI!HDU1D_JDPF(Z@4(/D;-
MZ0I6W>D`9\^EU>D`1<WX!*`V&6]!-$8]1LWI%D7=Z1!6W>D69X7J"`6H1@*=
M=AE'\0`'%NL(!$?Q``7-Z0)%1`$`E-WI`$5/ZI((W>D"O$CJ@WA$Z@H$E@<;
MZP0+F*M,\0`,S>D0O%Q&2>H(#$CJ!@O=Z0IXT^D`(^)&V4:'Z@L'#_+`+-SI
M`+P`)>8.N$8;ZP(+S>D"FDSK`PQ&ZD43W>D29T_JD0G-Z1:\3^I$&H;J"`8`
MDP:;L$;=Z19G]AA/ZM5C1_$`!P&3%NL(`D_JD`A'\0`#2.J!>,WI!B.&!]WI
M`"/>Z0`!#?4<?D+J"@+=Z0:KS>D``4CJ!@!)Z@@!W>D"B1KK`@J/I]?I`&=+
M\0`+B.H`",WI$JM/ZI4)S>D&`5)&W>D``4_P``M/ZMIJ6T:`&4KJ2QIY0<WX
M!*`&1@J8#T;-Z19GW>D09X;J"`:P1MWI%F<V&$?Q``<6ZP@`3^J4"$_JA'9(
MZH5XWND`14?Q``'-Z0H!40$`D=WI``$-]2!^S>D`14CJ!@1)Z@@%W>D&>-WI
M"KQ`Z@H`9T`N1B5&S>D*5KA&W>D`16:GU^D`9QOK``M,\0`,3^J3":096$9]
M0<WI$+PF1D_P``PO1LWI%F?=Z1)63^K;:MWI%F=*ZDP:A>H(!<WX!*"H1@*=
M=AE'\0`'%NL(!$_JD@A/ZH)V2.J#>)ZK1_$`!<WI`D73Z0`C1`$`E-WI`$4`
M)<WI`"-(Z@8"2>H(`]WI"HE$Z@H$W>D"JT.GU^D`9XCJ`@C-Z0(C&NL$"MWI
M`"-+\0`+S>D2JU1&DAE/ZMIJ>T%*ZD4:%D9/ZIP)'T;-Z19GW>D09P:;ANH(
M!LWX!*"P1MWI%F?V&$?Q``<6ZP@"1_$``\WI!B-C`0"3W>D`(T_JD`A(ZHQX
MA@="Z@H"W>D&JTGJ"`S>Z0`!&NL""@WU(GY+\0`+S>D0JT_P``M21EM&2.H&
M"]WI`GCB1ME&U@Z'Z@L'#_)D#-SI`+S-Z0::3^J5"1OK``NX1DSK`0Q&ZD,1
MW>D29T_J0AK-Z1:\ANH(!@J8`)'9#K!&W>D69P&1-AA'\0`'%NL(`$_JE`A/
MZH1V2.J%>-[I`$5'\0`!".``O]R\&X\`````UL%BR@````#-Z0H!W>D``0WU
M)G[-Z0!%2.H&!$GJ"`7=Z0:)W>D*O$#J"@`N1HCJ!`@E1LWI"E8/\N1WU^D`
M9QOK``O=Z0!%3/$`#%A&S>D2O*093_``#'U!3^K;:B9&2NI,&B]&S>D69]WI
M$%9/ZI,)W>D69X7J"`7-^`2@J$8"G7891_$`!Q;K"`1'\0`%S>D"140!`)3=
MZ0!%3^J2"$CJ@WB6!T3J"@3=Z0*KI*L`)1KK!`I+\0`+S>D0JU1&2>H("TCJ
M!@K=Z0IXT^D`(^8.S>D"JX?J"@</\D1[V^D`JT_JG`FX1AKK`@I+ZP,+1NI%
M$]WI$F?-Z1:K3^I$&X;J"`8`DP:;L$;=Z19G]AA/ZM5C1_$`!Q;K"`)/ZH!V
M3^J0"-[I``%(ZHQX`9-'\0`#S>D&(PWU*'[=Z0`CS>D``4CJ!@!)Z@@!W>D"
MB4+J"P+=Z0:K#_+(9]?I`&>(Z@`(S>D&`1KK`@K=Z0`!2_$`"U)&S>D2JX`9
M3_``"WE!3^K::@9&"I@/1LWI%F?=Z1!G2NI+&LWX!*!;1H;J"`9/ZI4)L$;=
MZ19G-AA'\0`'%NL(`$?Q``'-Z0H!40$`D=WI``%/ZI0(W>D*O$CJA7A`Z@H`
MI@<;ZP`+3/$`#,WI$+S>Z0!%6$9/\``,3^K;:DKJ3!H-]2Q^S>D`14CJ!@1)
MZ@@%W>D&>$_JDPEG0"Y&)4;-Z0I6N$;=Z0!%#_(`9]?I`&?-^`2@I!E]029&
M+T;-Z19GW>D25MWI%F>%Z@@%J$8"G7891_$`!Q;K"`1/ZI((3^J"=DCJ@WBJ
MJT?Q``7-Z0)%T^D`(T0!`)3=Z0!%`"7-Z0`C2.H&`DGJ"`/=Z0J)1.H*!-WI
M`JL/\I17U^D`9XCJ`@C-Z0(C&NL$"MWI`"-+\0`+5$;-Z1*KDAE/ZMIJ>T%*
MZD4:%D;-^`2@'T;-Z19GW>D09T_JG`D&FX;J"`:P1MWI%F?V&$?Q``<6ZP@"
M1_$``\WI!B-C`0"3W>D`(T_JD`A(ZHQXA@="Z@H"W>D&JTGJ"`S>Z0`!&NL"
M"@WU+GY+\0`+S>D0JT_P``M21EM&2.H&"]WI`GCB1ME&U@Z'Z@L'#_+H3-SI
M`+S-Z0::3^J5"1OK``NX1DSK`0Q&ZD,1W>D29T_J0AK-Z1:\ANH(!@J8`)'9
M#K!&W>D69P&1-AA'\0`'%NL(`$_JE`A/ZH1V2.J%>-[I`$5'\0`!S>D*`=WI
M``$-]3)^S>D`14CJ!@1)Z@@%W>D&B=WI"KQ`Z@H`+D:(Z@0()4;-Z0I6W>D`
M11OK``L/\E1'U^D`9TSQ``Q81LWI$KRD&4_P``Q]04_JVVHF1DKJ3!HO1LWI
M%F?=Z1!63^J3"=WI%F>%Z@@%S?@$H*A&`IUV&4?Q``<6ZP@$1_$`!<WI`D5$
M`0"4W>D`14_JD@A(ZH-XE@=$Z@H$W>D"J["K`"4:ZP0*2_$`"\WI$*M41DGJ
M"`M(Z@8*W>D*>-/I`"/F#H?J"@?-Z0*K#_*\.]OI`*M/ZIP)N$8:ZP(*2^L#
M"T;J11/=Z1)GS>D6JT_J1!N&Z@@&`),&F[!&W>D69_883^K58T?Q``<6ZP@"
M3^J`=D_JD`C>Z0`!2.J,>`&31_$``\WI!B,-]31^W>D`(\WI``%(Z@8`2>H(
M`=WI`HE"Z@L"W>D&J]"GU^D`9XCJ``C-Z08!&NL""MWI``%+\0`+3^J5"5)&
M@!G-Z1*K>4%/\``+!D8*F`]&S>D69]WI$&=/ZMIJ2NI+&LWX!*"&Z@@&6T:P
M1MWI%F<V&$?Q``<6ZP@`3^J4"$_JA'9(ZH5XWND`14?Q``'-Z0H!40$`D=WI
M``$-]3A^S>D`14CJ!@1)Z@@%W>D&>-WI"KQ`Z@H`9T`N1B5&S>D*5KA&W>D`
M1::GU^D`9QOK``M,\0`,3^J3":096$9]0<WI$+PF1D_P``PO1LWI%F?=Z1)6
M3^K;:MWI%F=*ZDP:A>H(!<WX!*!A1JA&`IUV&4?Q``<6ZP@$3^J2"$?Q``5(
MZH-XMJO-Z0)%E@=$`0"4T^D`(]WI`$4`)<WI`"-(Z@8"2>H(`]WI"HE$Z@H$
MW>D"JX.GU^D`9XCJ`@C-Z0(C&NL$"MWI`"-+\0`+5$;-Z1*KDAE/ZMIJ>T%*
MZD4:%D;-^`2@'T;-Z19GW>D09T_JD0D&FX;J"`:P1MWI%F?V&$?Q``<6ZP@"
M1_$``\WI!B-C`0"3W>D`(T_JD`C=Z0:\2.J!>$+J"@*&!QOK`@M/\``*3/$`
M#,WI%KQ:1D_P``O-Z0"K2.H&"DGJ"`O=Z0)XT4;>Z0`!A^H)!]8.VD8`ELWI
M$)JX1MWI$JM/\``,5*?7Z0!G8T:*Z@@*-A@`F$]!S>D&9T#J3![01@J85@'=
MZ0:K3^J5"\WX`.``)QKK``K8#@&0&NL(`-WI`(E/ZI0*2NJ%>KJM2.H&"$OJ
M"@$0ZP@`3^J$>(M&!D9*Z@@`S>D`9]7I`&>"1MWI`(G-Z0JK04;=Z1")R`Z(
MZ@H(#_+4"]OI`*L:ZP8*5D;=Z0"K0.I+'MWI%JL"F(KJ"`K-^!C@-AC01MWI
M`*M91L@.448'D$P!`"``(<WI`@$6ZP@`W>D&>)8(`I9/ZH)Z`IDG0\89W>D`
M14'JC'$"D=WI!`&9"``C`Y&`&=WI#F?=Z0*)`"<"1AJ82.H*"-WX],(`(<#I
M`"/=Z0PC"IND&/88&YNB1MWI%$7`Z09G`"73^`#@$)OD&-WI"",`(Q+K"`+T
M19!&4D;`Z0(C`D;"Z0A%0$;"Z00!`]$-]3]]O>CPC_SW4NH`O];!8LH`````
M`"@\T"WI^$-+\C@3P/("`]/X`)"Y\0`/+M`%>#TM&+\`+12_`24`)171V?@`
M0'RQ@$8/1DY&*D9!1B!&_/=4ZQ"Y8UT]*P_05O@$3P`L\M$@1KWH^(,%1A7X
M`3\]*QB_`"OYT2T:X.?)ZP8&:!P@1+80/F"]Z/B#2$:]Z/B#<$=PM4OR0!7`
M\@(%@K`K:$OR.!8$1L#R`@8!DVE&($;_]Z__J+$`F#%H`>N``UIH0?@@(``J
M\=`$,U/X!"]#^`0L`"KYT6E&($;_]YK_`"CIT0&:*VB:0@'1`K!PO?SWW.DM
MZ?!/2_)`%0MXP/("!0Q&*F@]*X6P"+\!-`9&`Y(@1OSW2NH"J0=&,$;_]WG_
M@D8`*%?0_/=`ZH="2MD"FTOR.!G`\@()3^J#"#!X/2@8OP`H%+\!(``@!]`P
M1A#X`3\]*QB_`"OYT8`;`C?9^`"0.$1+\C@7_/?\Z<#R`@=)^`@``"ALT#IH
M<1P"F#-X4O@@```K&+\]*P-P"=!"'!'X`3L01@`K&+\]*P+X`3OVT0)&/2,#
M<!3X`3L"^`$_`"OYT0`@`YHK:)I"3-$%L+WH\(\*\?\P%/@!.P#X`3\`*_G1
M[N=+\C@9P/(""=GX`+#;^```B+-;1E/X!"\*\0$*`"KYT0KQ`@&)`$OR:!/`
M\@(#&FAZL5A&_/=BZ<GX``#PL4_JB@@*\0$#`")`^",@S?@(H(GG"$8!(AI@
M_/>8Z0&0:+%/ZHH(649"1OSW^.@!FQA&R?@`,.7G@D8((=3G3_#_,*[G_/<H
MZ0"_+>GP04OR0!7`\@(%GK`K:!V3$+$#>`=&,[D=FBMHFD)2T1ZPO>CP@?SW
M8.D&1@`H\]`P1OSW$NJ8L\-\+BLWT`#Q$P0X1OSW@NF`1B!&_/=^Z4!$`C#\
M]U;I1O+@<\#R`0-/\/\R`2$!E`"7@$;\]XSI048"J@,@_/<*Z@$P0$8%T`:;
M`_1P0[/U@$\9T/SW[.A`1OSWI.@P1OSWX.D`*,O1,$;\]Q+J.$;\][CHM.<#
M?0`KO=`N*\+10WT`*[C0ON?_]YW_Y.?\]\#H<+5+\D@4P/("!"!H_/?^Z=#X
M@#`@:%YH_/?XZ9#X95`@:/SW].D%\'\%0V@;BL/S"`-%ZL,5=8`@:/SWZ.G0
M^(`P(&A=:/SWXNE&]O`A`"+`\@$!_/<FZ>AA(&C\]];IT/B`,"!H76C\]]#I
MT/C@-"!H*V+\]\KIT/B`,"!H76C\]\3IT/C\,"NQ(&C\][[IT/C\,!MO:V(`
M)2!H_/>VZ=#X@#`@:%MHG6+\][#IT/B`,"!H6VB=8?SWJ.G0^(`P(&A<:/SW
MHNG0^!@RXV)PO3BU2_)(%,#R`@0%1B!H_/>6Z2E&`/6$<@,@_/>$Z0BQ`"`X
MO2!H_/>*Z=#X&#$#]'!#L_6`3PG0(&C\]X#IT/@8,0/T<$.S]2!/Z=$H1@(A
M_/<>Z;#Z@/!`"3B]\+5+\D`4K?6`7<#R`@2#L"-H#?6`509&!#5&\NAP#T;`
M\@$``:E`]O]R*V#\]SCH`"@CW44>`:M;7>NQ!48J1B\A`:C\]_#HP+%+\D@3
MP/("`QAH_/=$Z2M&`:HQ1OSW".D-]8!3!#,::"-HFD(1T0WU@%T#L/"]`"W@
MT4OR2!/`\@(#&&C\]RSI.D8Q1OSW`NCFY_OWWN]+\D@3P/("`Q"U&&C\]QSI
M1O)D<T'R[%)&\OAQP/(!`\#R`0+`\@$!O>@00/SW>+@0M4OR2!3`\@($@K`@
M:/SW!.G_]]W_(&C\]_[H1O;P(T;RN3)&]A0!P/(!`\#R`0(`D\#R`0$`)`&4
M_/>,Z`*P$+T`OW"U2_)`%*WU`%W`\@($AK`C:`WU`%(4,A-@_/<*Z$;V.`)&
M]BP#P/(!`L#R`0,!D@$A0?(!`@"0`ZC\]R3H`"@BVPWU@%$#J$_T@%(0,?OW
MHN\%'AC;:!S[]]+O!D:HL0WU@%$J1A`Q^_=$[S!&`"-S50WU`%,4,QIH(VB:
M0@;1#?4`70:P<+T`(/+G\>?[]USO`+__][2_+>GP3TOR0!:M]8!=P/("!H>P
M,V@-]8!2!$84,D;V0``/1L#R`0`$J1-@__?U_"\A!48@1OOWR.^@L4;V3``A
M1L#R`0#_]UC]($8-]8!3%#,::#-HFD)`\)"`#?6`70>PO>CPCR!&^_>D[T;V
M7`'`\@$!@48X1OSW$NB"1@`HW-!&]CP'1O9H",#R`0?`\@$(FO@`,``K"+^Z
M1BVQ448H1OOWLNX`*$S04$;[]X+O"NL``Q/X`3PO*PC10QX`(5-$&7`!.!/X
M`2TO*OG0"?$!`QA$L/6`7[#:1O9@`TOR2!M/](!2`2'`\@$#`I3-^`2`!:C-
M^`"@P/(""_OW>._;^```_/<<Z`6I`/6$<@,@^_?R[U"YV_@``/SW$.C0^!@Q
M`_1P0[/U`$\6T$;V7`$`(,#R`0'[][+O@D:Z\0`/I]%[YT;V7`'`\@$!^_>H
M[X)&NO$`#YS1<.<!(06H^_>8[P`HXM%&]DP`!:G`\@$`__?#_`6H^_=([V?G
M^_>:[@"_`W@[L4(<+RL(OQ!&$O@!.P`K^-%P1P"_.+6(LP5X!$9UL_OW!N\!
M.",8G$(,TB)<+RHOT5H>`N`9>"\I*M&B0A-&`O'_,O?1G$(7T`$[`N`1>"\I
M!-&<0AI&`_'_,_?3$AN3'+/U@%\2V`$R(49/](!3$DC[]U;N$$@XO2\M%-$"
M(/OWLNX#1A"Q+B(:@#B]`"`XO5H>`N`9>"\IUM"40A-&`O'_,O?3SN=&]F@`
MP/(!`+WH.$#[]^6^`+]LL0(`\+6-L%]-`JQ+\D`6P/("!@_--V@/Q`_-"Y<M
M:`_$1O9L`,#R`0`E@/_W%OQ&]G@`P/(!`/_W$/Q&]H``P/(!`/_W"OQ&]HP`
MP/(!`/_W!/Q&]I0`P/(!`/_W_OM&]J0`P/(!`/_W^/M&]D``P/(!`/_W\OM&
M]K``P/(!`/_W[/M&]KP`P/(!`/_WYOM&]L@`P/(!`/_WX/M&]DP`P/(!`/_W
MVOM&]M0`P/(!`/_WU/M&]N``P/(!`/_WSOM&]NP``:G`\@$`__>'^P%&*+%&
M]KP`P/(!`/_W[_M&]@`0`:G`\@$`__=X^P%&*+%&]A00P/(!`/_WX/M&]B`0
M`:G`\@$`__=I^P%&J+%&]D``P/(!`/_WT?M&]E`11O:4`,#R`0'`\@$`__?'
M^PN:,VB:0B71#;#PO4;V,!`!J<#R`0#_]TK[`48PL4;VL`#`\@$`__>R^]_G
M1O9$$0HBP/(!`0WQ&0#[]ZSN`"C4T4;VL``-\2,!P/(!`/_WGOO+Y_OW>.T`
MOW!G`0`PM4OR0!1+\BP5P/("!"-HP/("!8.P*&@!DT,<!=`!FB-HFD(2T0.P
M,+U&]K``:4;`\@$`__<,^S"Q`'@`*!B_,"@4OP$@`"`H8.CG^_=,[0BU^_<(
M[?OW^NP`L0!H"+TMZ?!'!T8L3(ZP!JU+\D`8P/(""`_,V/@`8`_%E.@'``:<
M#9:%Z`<`[+%&]EP)!JW`\@$)!N`Y1OOWS.S8L57X!$^$L06I($;_]]+Z!D80
ML0-X`"OOT2!&.4;_]SG[5?@$3P`L[M$-FMCX`#":0B#1#K"]Z/"'.$;[]X;M
M@D8P1OOW@NU01`(P^_=:[4;V8`,"EL#R`0/-^`203_#_,@"7`2&"1OOWCNU1
M1B!&__<0^\7G^_?J[`"_E&<!`"WI\$\%1L-,K?4!39&P2_)`$P3Q#`P2KY3H
M!P#`\@(#"9,-\6`.)#05KH?H!P"\Z`\`KN@/`)SH`P`)FX[H`P"4Z`<`#?4!
M1!MH/#2&Z`<`1O9``!&IP/(!`"-@__=J^B"Q`W@$1@`K0/"&@?_W8O^`1@`H
M4]!`1OOW*.U```$P^_<`[9CX`"`&1@1&>K%&]EP3`)(@1D_P_S+`\@$#`2'[
M]S+M&/@!+P(T`"KOT1B8&*P8N13@5/@$#XBQ$:G_]SGZ@$8`*/;0`W@`*_/0
M__<E_``H[]!`1OOW).V!1G"[$IQ4LR-X3_`!"#NY)>!7^"A`%+,C>`CQ`0CS
ML2!&__<-_``H\]`@1OOW#.T`*.[0@484X/OW!NT`*$#P.8%6^`0+`"@`\"Z!
M$:G_]P/Z`"CUT`-X`"ORT.SG3_``"4A&1O9H"_OWPNS`\@$+!$8P1OOWO.P@
M1`#R!$0@1OOWDNQ&]G`21O9D$\#R`0+`\@$#`I(!(4_P_S(#ELWX`)#-^`2P
M@D;[]\#L4$9/].!Q^_?8[`$P*]!+\D@6P/("!C!H^_=:[5%&`/6$<@,@^_=(
M[:"S2_)0$4;V^!+`\@(!*V@(:,#R`0+-^`"@`2'[]]SL`"`-]0%#/#,::`F;
M&VB:0D#PHX(-]0%-$;"]Z/"/^_>&[`%H$2G.T$OR4!!&]G@2P/("`"MH`&C`
M\@$"`9$!(<WX`*#[][CL`"#:YS!H^_<<[=#X&#$#]'!#L_6`3\#1,&C[]Q+M
MT/@@<?OWANN'0K?1,&C[]PCMT/@8,</S"`.S]>!_K=$@1OOW%.P1J01&1O9$
M,,#R`0#_]V3Y`"@`\%J"+FC[]U;L`48P1O_W3OP&1@`H`/!/@C!&^_<@[`,H
M!T81W00X1O:T$3!$P/(!`?OW0.M`N00O`/#5@3=$%_@%/"\K`/#/@?_W%/XP
MN0%&,$;[]]KK#)``*&/11O90$4;VL`#`\@$!P/(!`/_WFOE&]O`G^_?FZT;V
MU!/`\@$'S?@$L`.7P/(!`\WX`*!/\/\R`2&X1@`F5T8"D"!&^_?\ZQG@L&<!
M`/OW\.L#:!$K&M'[]\CK1O;D$P$VS?@0@`.6*D;-^`2PP/(!`P"7`2$"D"!&
M^_?@ZT_TX'$@1OOW^.M#'`5&W]"Z1E!&^_<`ZT;V0``A1L#R`0#_]U/Y($;_
M]^C]($8LY__WY/T@1OOWTNLFYT;V5!@-(,#R`0AWYH!&<.9/\/\S;_`1`@(E
M`)7[]U+K3ZD&(@R8^_?(ZIWX/#$CN9WX/3%#*P#P?($`)0`B`",`E0R8^_<^
MZ]FAT>D``=JCT^D`(SR5S>D@`2RIS>DB(PU&UZ'1Z0`!UZ/3Z0`C#93-Z20!
MUJ'1Z0`!S>DF(P`B`"/-^#B@S>DH(\WI*B/-Z1X!S?@\L$_T`$)/J0R8^_>,
MZ@0>=-W=Z2@C3^K$"D_P``DF1AKK`@B910B_D$5/ZN1WW>DJ(P+2`3)#\0`#
M<0\\F$'JQP$&D7D/!Y'=Z09GS>DHB;887T$R1CM&S>DJ(P`H2M#`\4`('JN@
M10#Q.``81$^IJ+^@1D)&^_=TZCR;0T0\DT`KOM%/JQZHR.L$!)A$^_=%_3\L
M)]VD\4`#"/%`#`J3G`D$\0()".N)&:SQ0`:N1C!H$#96^`P<=T96^`@L#O$0
M#E;X!#QF10_'\=$>J/OW)?T&\4`,S$7GT6,<"IH(ZX,8HNN$%$%&2",B1BA&
M^_>.ZCR4A><-]9YXRN<,J)#H$0S[]XSK'JLHG8`@*I[%\\4"F1A3'#@K@?@X
M``+Q.0``\Z.`'JO"\3<"&$0`(?OW`NL>J"H.,PZ-^.M@C?CO4`WUB'B-^.@P
M,PR-^.P@-@J-^.DP*PR-^.I@+0J-^.TPC?CN4/OWVOP>GPWR#Q4@GB*8))D[
M#(WX_3`Z#B:;C?C_<#\*C?@#88WX_G`W#HWX!P&-^`!Q-PR-^`L1-@J-^`%Q
M/Z^-^`)A!@Z-^`\QC?@$808,C?C\(``*C?@%849&C?@&`0@.C?@(`0@,"0J-
M^`D!C?@*$1D.C?@,$1D,&PJ-^`T1C?@.,0'@%_@!+T;V7!,`DC!&P/(!`T_P
M_S(!(?OW=NJO0@;Q`@;NT4;V\"%&]L03S?@(@,#R`0'-^`2P`"`#D<#R`0/-
M^`"@3_#_,HCX*``!(2!&^_=:ZH'F;6@`+3_T+:XH1OOW-.H#*'_V)ZX$.$;V
MO!$H1,#R`0'[]U;I`"@(ORY&&N8>J\+Q/P(81``A^_=>ZAZH^_=/_``C+),M
MDRZ3+Y,PDS&3,I,SDS23-9,VDS>3.),YDTGGG?@^,4$K?_1_KIWX/S%#*W_T
M>JZ=^$`Q2"M_]'6NG?A!,44K?_1PK@"53_#_,PR=;_`Y`BA&^_>LZ4^I*$8I
M(OOW(NE&]O`B1O;$$T^IP/(!`@*1`Y+`\@$#S?@$L$_P_S+-^`"@`2$@1OOW
M\ND9YBYHKN7[]U#I`+^O\P"`B:O-[P````#^W+J8`````'94,A``````\.'2
MPP`````!(T5G`````"WI\$]+\D`3A;#`\@(#2_)(%P&3P/("!QMH.&@#D_OW
M;NH!(P*I@/AA,$;VE`#`\@$`_O?1_ABQ`W@Q*P#PV8#_]][Z.&A,\F`F^_=8
MZD;V3"'`\@$!"R,!(OOW<ND`*`#PS(#`\@(&`FE6^/0\`2O2^!B0.]U+\D@:
M`"7`\@(*`20DX`)H3_2`8U;X\`S`\B`#D6A0^"2`"T"S]8!O"+\1:0K0VO@`
M`/OW*.K;^``0`B,`(OOW#ND!1D!&^_>$Z%;X]#R`N0$T`36C0@S=.&C[]Q3J
M`",J1DE&^_?&Z8-&`"C/T5;X]#Q:'JI"<M`X:$OR2!3[]P+J1O94(<#R`0$#
M(P$BP/("!/OW&ND%1H"Q(&C[]_3I*VE&]E@BP/(!`AEH^_?&Z"MI&VB;:%L"
M`/&W@#AH2_)(%/OWX.E&]F`AP/(!`0,C`2+`\@($^_?XZ`5&F+%&]DP``JG`
M\@$`_O<[_H!&(&BX\0`/`/"/@/OWQNDK:4)&&6C[]YKH.&A+\D@9^_>\Z0`B
M`JE,\F`DP/(""<#R`@0#1D;V0`#`\@$`@_AA(/[W&/Z`1D;X[`Q`LT_TX''[
M]Q;I0AP#1A$H&+\!*GW8`9L#FAMHFD)VT06PO>CPCP$KBMT!)#AH`33[]X[I
M24;[]Q3H5OCT/*-"]-Q]YT-X`"L_]"6O(>?`\@(&=>=4^/`,__=-^T3X[`P`
M*$[0*FE/](!CP/(@`Q)HD6@+0+/U@&\(OQ!I"=#9^```^_=DZ2EI0D8"(PEH
M^_=*Z%;X\$PA1OKW\.\J:4_T@&,D:,#R(`,2:)%H"T"S]8!O"+\2:09&"=`X
M:/OW2.DI:0`B`B,):/OW+N@"1D;VB"`S1B%&P/(!`/OWENC[]S;I5OCP+"MI
M$6@8:/[WO_]MYR!H^_<LZ2MI&6C[][3H0.=&]F0@P/(!`/OW?NCZ]]CO5/CP
M'$;VL"!"1L#R`0`):/OW<N@XM05&__<^^0-X!$8[L4(<+RL(OQ1&$O@!.P`K
M^-'_]TGZ`"@8OP`M"M`K>$.Q1O9P$2!&P/(!`?KW5N^$0@#0.+TH1KWH.$#^
M]X*^$+5+\D@4P/("!"!H^_?FZ$_P_S'Z]^#O(&C[]^#H1?*I0<#R`0$`(KWH
M$$#[]ZJX`DM[1`.Q&VCZ]Y"_&DH!`"WI^$,'1@M.B$8+39%&?D3Z]Q3O?41V
M&[80"=``)`$T5?@$.TI&048X1IA'M$+VT;WH^(/.1P$`Q$<!`'!'`+\(0"WI
M"("]Z`$``@!P97)L>'-I+F,```!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@
M("`@("`@(``````D:P$`-&L!`#QK`0!$:P$`3&L!`&!K`0``````'&L!`#QH
M`0``````%&D!`!AI`0`0:P$`1&@!`!AK`0``````_&H!``1K`0``````)7,O
M)7,````O<')O8R]S96QF+V5X90``1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A
M9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````"]P<F]C+R5I+R5S`&5X90`N
M````4$%27U1%35``````4$%27U!23T=.04U%`````#H````E<R5S)7,``"\`
M``!015),-4Q)0@````!015),3$E"`%!%4DPU3U!4`````%!%4DQ)3P``4$%2
M7TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@```%!!4E]$14)5
M1P```%!!4E]#04-(10```%!!4E]!4D=#`````%!!4E]!4D=67S```%!!4E]'
M3$]"04Q?1$5"54<`````4$%27T=,3T)!3%]435!$25(```!005)?5$U01$E2
M``!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@````!005)?0TQ%
M04X]```Q````4UE35$5-```E,#)X`````"5S)7,E<R5S`````'!A<BT`````
M)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE
M9"`H97)R;F\])6DI"@``<&%R;``````N<&%R`````"5S)7-C86-H92TE<R5S
M```E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E<P`````E<SH@<')I
M=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E
M(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!!4D=6`````!@```!P
M97)L`````#````!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``
M```E<SH@97AE8W5T:6]N(&]F("5S(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z
M(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A
M:6QE9"`H97)R;F\])6DI"@`````M90``+2T``%5315(`````55-%4DY!344`
M````5$5-4$1)4@!435``+W1M<`````!,1%],24)205)97U!!5$@`3$E"4$%4
M2`!,24)205)97U!!5$@`````1%E,1%],24)205)97U!!5$@```!32$Q)0E]0
M051(``!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B
M?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA
M9V4@7U]P87)?<&P["FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I
M;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL
M93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE
M.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H
M)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T
M96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@
M<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP
M.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@
M)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G
M+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-5
M1D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C
M(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F
M("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB
M<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N
M("1T;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE
M;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL
M(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3
M<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z
M("D*+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS
M.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/
M5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*:68@*&5X:7-T<R`D14Y6>U!!
M4E]!4D=67S!](&%N9"`D14Y6>U!!4E]!4D=67S!]("D@>PI`05)'5B`](&UA
M<"`D14Y6>R)005)?05)'5E\D7R)]+"`H,2`N+B`D14Y6>U!!4E]!4D=#?2`M
M(#$I.PHD,"`]("1%3E9[4$%27T%21U9?,'T["GT*96QS92!["F9O<B`H:V5Y
M<R`E14Y6*2!["F1E;&5T92`D14Y6>R1??2!I9B`O7E!!4E]!4D=67R\["GT*
M?0IM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@
M*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG
M*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W
M:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O
M7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I
M.PI?<V5T7W!A<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I
M.PI["FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@
M)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F
M.PIS965K(%]&2"P@+3@L(#(["G)E860@7T9(+"`D8G5F+"`X.PIL87-T('5N
M;&5S<R`D8G5F(&5Q(")<;E!!4BYP;5QN(CL*<V5E:R!?1D@L("TQ,BP@,CL*
M<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`M,3(@+2!U;G!A8VLH(DXB
M+"`D8G5F*2P@,CL*<F5A9"!?1D@L("1B=68L(#0["B1D871A7W!O<R`]("AT
M96QL(%]&2"D@+2`T.PIM>2`E<F5Q=6ER95]L:7-T.PIW:&EL92`H)&)U9B!E
M<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F
M+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T
M<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D8W)C
M(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z
M('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z
M+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&
M2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I
M(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`H)&]U
M="P@)&9I;&5N86UE*2`](%]T96UP9FEL92@D97AT+"`D8W)C*3L*:68@*"1O
M=70I('L*8FEN;6]D92@D;W5T*3L*<')I;G0@)&]U="`D8G5F.PIC;&]S92`D
M;W5T.PIC:&UO9"`P-S4U+"`D9FEL96YA;64["GT*)%!!4CHZ2&5A=GDZ.D9U
M;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D
M9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%2
M7U1%35!]("D@>PIM>2`D9FEL96YA;64@/2`B)$5.5GM005)?5$5-4'TO)&)A
M<V5N86UE)&5X="(["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PIO<&5N
M(&UY("1O=70L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*8FEN;6]D92@D
M;W5T*3L*<')I;G0@)&]U="`D8G5F.PIC;&]S92`D;W5T.PI]"F5L<V4@>PHD
M<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D=6QE
M0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C
M+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*
M?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`
M7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D9FEL
M96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R![
M"FUY("1K97D["F9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PIN97AT
M('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*)&ME>2`]("1?.R!L87-T.PI]"F1E
M;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D["GT@
M;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N86UE
M+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)
M3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I
M;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D9FEL96YA
M;64M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R;B`D9F@["GT*96QS
M92!["FUY("@D;W5T+"`D;F%M92D@/2!?=&5M<&9I;&4H)RYP;2<L("1F:6QE
M;F%M92T^>V-R8WTI.PII9B`H)&]U="D@>PIB:6YM;V1E*"1O=70I.PIP<FEN
M="`D;W5T("1F:6QE;F%M92T^>V)U9GT["F-L;W-E("1O=70["GT*;W!E;B!M
M>2`D9F@L("<\)RP@)&YA;64@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G)E
M='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T
M(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R
M.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA
M;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H
M)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII
M9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA
M;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^
M("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI
M<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<
M,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"FUY($!P87)?
M87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I
M.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D55
M4T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE
M<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=6
M6S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?
M8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@
M('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD[
M"FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T
M($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*
M96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC
M.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I
M=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A
M9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S
M92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G
M<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS
M:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D
M,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G
M<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@
M)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G
M.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R
M.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]
M*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U
M:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@
M0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X
M:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O
M=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII
M<#L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F
M:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#
M86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D
M9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@
M)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV
M93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@
M)"$B.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]
M("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI>
M<&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@
M("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L("0O(#T@7#0["FEF("AD
M969I;F5D("1P87(I('L*;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A
M.B`D<&%R(CL*8FEN;6]D92A005(I.PID:64@(B1P87(@:7,@;F]T(&$@4$%2
M(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["GT*0W)E871E
M4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/
M.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/
M.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E
M*"1F:"D["B0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@
M.B!U;F1E9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(@/2!S8V%L87(@
M/%]&2#X["FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^
M("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13
M=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A
M9&5R+"`D,"D*?0IF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2![
M"FUY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V
M86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%2
M7R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D
M:V5Y*2`N("(])'9A;"(["B1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA
M9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T
M*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I.PHD+R`]('5N9&5F.PII
M9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U
M;&5S*"D["FUY($!I;F,@/2!S;W)T('L*;&5N9W1H*"1B*2`\/3X@;&5N9W1H
M*"1A*0I](&=R97`@>PHA+T)31%!!3B\*?2!G<F5P('L**"1B=6YD;&4@;F4@
M)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!]
M(&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)
M3D,["FUY("5F:6QE<SL*+UY?/"@N*RDD+R!A;F0@+64@)#$@86YD("1F:6QE
M<WLD,7TK*R!F;W(@:V5Y<R`E.CH["B1F:6QE<WLD7WTK*R!F;W(@=F%L=65S
M("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1]
M.PIM>2`E=W)I='1E;CL*9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PIM
M>2`H)&YA;64L("1F:6QE*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF
M("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE
M(#T@)%\["FQA<W0["GT*96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI
M7%HO:2D@>PHH)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L
M<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@
M)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L**"1F:6QE
M+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I
M<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA
M<W0["GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D
M=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I
M;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A
M8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*
M<7$H(BXN+BD**3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C
M;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)3$4L("<\
M)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["F)I;FUO
M9&4H1DE,12D["B1C;VYT96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL
M92D*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z
M<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M
M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R
M:71T96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^
M<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I
M;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#
M4D,S,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG
M+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]
M"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C
M:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A
M8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM
M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ
M4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[
M($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T
M.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@
M979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA
M7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I
M('L*)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E
M('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM
M;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]
M"B1C86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM
M93L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H
M95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D
M8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M
M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD[
M"B1F:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T
M('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*
M<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]
M"FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I
M;&4M/FYE=SL*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE
M("(D(3H@)$`B.PHD>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O
M9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D
M0"(["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE
M>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=]
M.PIO=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I
M*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@
M<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M
M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY
M("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S
M<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#
M;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE
M?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@
M)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-
M4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?
M(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K
M:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S
M(&%T("(D9&5S=%]N86UE(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I
M;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B1M96UB97(M
M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@
M)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@
M*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE
M<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;
M("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M
M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-
M17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E
M871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E
M;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S
M96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I
M;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE
M("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I
M<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97([
M"G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R
M;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A
M<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(
M96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER
M92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,
M;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E
M<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I
M<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE
M879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*
M<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A
M;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5
M=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!]
M.PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE
M=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@
M?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%2
M7U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T
M96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D
M14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!4
M35`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@
M9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D
M=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I
M9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,
M;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*
M?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED
M.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6
M>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*
M;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A
M8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF
M("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O
M9VYA;64I*5LY72D@>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*
M<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D9F@L(&UY("1B=68L(#8["FEF
M("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIS>7-R
M96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@
M+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIM
M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ
M4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[
M($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T
M.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@
M979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA
M7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I
M('L*)&-T>"T^861D9FEL92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I.PI]
M"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE
M(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E
M*"1F:"D["GT*?0HD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M
M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PI]"F-L
M;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP
M9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]4
M14U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*
M?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM0
M05)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&5X
M="P@)&-R8RD@/2!`7SL*;7D@*"1F:"P@)&9I;&5N86UE*3L*)&9I;&5N86UE
M(#T@(B1P87)?=&5M<"\D8W)C)&5X="(["FEF("@D14Y6>U!!4E]#3$5!3GTI
M('L*=6YL:6YK("1F:6QE;F%M92!I9B`M92`D9FEL96YA;64["G!U<V@@0'1M
M<&9I;&4L("1F:6QE;F%M93L*?0IE;'-E('L*<F5T=7)N("AU;F1E9BP@)&9I
M;&5N86UE*2!I9B`H+7(@)&9I;&5N86UE*3L*?0IO<&5N("1F:"P@)SXG+"`D
M9FEL96YA;64@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G)E='5R;B@D9F@L
M("1F:6QE;F%M92D["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE
M9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]
M?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D
M,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%
M3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O
M9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q
M*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA
M;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L
M("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US
M("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)$-O
M;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI
M="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT
M(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!
M4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B@H
M)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N
M9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA
M;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII
M9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PHD
M<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@
M)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I
M"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H
M*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<
M+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO
M.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?
M:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@
M*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@
M,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@
M4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*9&5L971E("1%3E9[)U!!4E\G
M+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2![
M"B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@
M97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A
M;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["FEF("@D
M14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L
M<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A
M;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I
M*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,
M14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*
M:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP
M<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I
M9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF
M:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP
M('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP
M86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2
M.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q*'!A
M<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@
M<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@+64@)'!R;V=N86UE
M.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+
M7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/
M4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2
M(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@
M)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`0'/_?P$`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````&T;`0!5&P$```````$````!`````0````4"```!````
M5`(```$```"G`P``#````%05`0`-````6&<!`!D```#TK@(`&P````0````:
M````^*X"`!P````$````]?[_;[0!`0`%````=`P!``8```!T!0$`"@```#\%
M```+````$````!4``````````P````"P`@`"````*`(``!0````1````%P``
M`"P3`0`1````]!(!`!(````X````$P````@```#^__]OE!(!`/___V\#````
M\/__;[01`0``````````````````````````````````````````````````
M````````````````KP(```````````!@%0$`8!4!`&`5`0!@%0$`8!4!`&`5
M`0!@%0$`8!4!`&`5`0!@%0$`8!4!`&`5`0!@%0$`8!4!`&`5`0!@%0$`8!4!
M`&`5`0!@%0$`8!4!`&`5`0!@%0$`8!4!`&`5`0!@%0$`8!4!`&`5`0!@%0$`
M8!4!`&`5`0!@%0$`8!4!`&`5`0!@%0$`8!4!`&`5`0!@%0$`8!4!`&`5`0!@
M%0$`8!4!`&`5`0!@%0$`8!4!`&`5`0!@%0$`8!4!`&`5`0!@%0$`8!4!`&`5
M`0!@%0$`8!4!`&`5`0!@%0$`8!4!`&`5`0!@%0$`8!4!`&`5`0!@%0$`8!4!
M`&`5`0!@%0$`8!4!`&`5`0!@%0$`8!4!`&`5`0````````````````#_____
M;&L!`$=#0SH@*%5B=6YT=2],:6YA<F\@-"XY+C(M,C!U8G5N='4Q*2`T+CDN
M,@!'0T,Z("A58G5N='4O3&EN87)O(#0N.2XR+3$P=6)U;G1U,3$I(#0N.2XR
M`$$T````865A8FD``2H````%-RU!``8*!T$(`0D""@02!!,!%`$5`1<#&`$9
M`1H"&P,<`2(!`"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+D%"22UT86<`+FYO
M=&4N9VYU+F)U:6QD+6ED`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N
M=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96PN9'EN`"YR96PN<&QT`"YI
M;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+D%232YE>&ED>``N96A?9G)A;64`
M+FEN:71?87)R87D`+F9I;FE?87)R87D`+FIC<@`N9'EN86UI8P`N9V]T`"YD
M871A`"YB<W,`+F-O;6UE;G0`+D%232YA='1R:6)U=&5S````````````````
M``````````````````````````````````````````L````!`````@```%0!
M`0!4`0``&0```````````````0`````````3````!P````(```!P`0$`<`$`
M`"````````````````0`````````(0````<````"````D`$!`)`!```D````
M```````````$`````````#0```#V__]O`@```+0!`0"T`0``P`,```4`````
M````!`````0````^````"P````(```!T!0$`=`4````'```&`````0````0`
M```0````1@````,````"````=`P!`'0,```_!0`````````````!````````
M`$X```#___]O`@```+01`0"T$0``X`````4``````````@````(```!;````
M_O__;P(```"4$@$`E!(``&`````&`````P````0`````````:@````D````"
M````]!(!`/02```X````!0`````````$````"````',````)````0@```"P3
M`0`L$P``*`(```4````,````!`````@```!\`````0````8```!4%0$`5!4`
M``P```````````````0`````````=P````$````&````8!4!`&`5``!@`P``
M```````````$````!````((````!````!@```,`8`0#`&```F$X`````````
M````"`````````"(`````0````8```!89P$`6&<```@```````````````0`
M````````C@````$````"````8&<!`&!G```00``````````````$````````
M`)8````!``!P@@```'"G`0!PIP``"`````T`````````!`````````"A````
M`0````(```!XIP$`>*<```0```````````````0`````````JP````X````#
M````]*X"`/2N```$```````````````$`````````+<````/`````P```/BN
M`@#XK@``!```````````````!`````````##`````0````,```#\K@(`_*X`
M``0```````````````0`````````R`````8````#`````*\"``"O`````0``
M!@`````````$````"````-$````!`````P````"P`@``L```)`$`````````
M````!`````0```#6`````0````,````DL0(`)+$``!````````````````0`
M````````W`````@````#````.+$"`#2Q``!$$``````````````(````````
M`.$````!````,``````````TL0``5P```````````````0````$```#J````
M`P``<```````````B[$``#4```````````````$``````````0````,`````
?`````````,"Q``#Z```````````````!````````````
